sqlobject.tests.test\_ForeignKey\_cascade module
================================================

.. automodule:: sqlobject.tests.test_ForeignKey_cascade
    :members:
    :undoc-members:
    :show-inheritance:
